@@ -50,3 +50,9 @@ CREATE TABLE IF NOT EXISTS traces
     SERVER      VARCHAR (50),
     EXP_ID      VARCHAR (100)
 );
+
+CREATE TABLE IF NOT EXISTS metadata
+(
+    EXP_ID  VARCHAR(100) NOT NULL,
+    DATA JSON NOT NULL
+)
\ No newline at end of file
